==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm2015/lib/GridColumnPinOptionsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GridColumnOptionsSimpleSectionBaseDescriptionMetadata } from "./GridColumnOptionsSimpleSectionBaseDescriptionMetadata";
import { GridColumnPinOptionsDescription } from "./GridColumnPinOptionsDescription";
/**
 * @hidden
 */
export let GridColumnPinOptionsDescriptionMetadata = /*@__PURE__*/ (() => {
    class GridColumnPinOptionsDescriptionMetadata extends Base {
        static b(a) {
            if (GridColumnPinOptionsDescriptionMetadata.a == null) {
                GridColumnPinOptionsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                GridColumnPinOptionsDescriptionMetadata.c(GridColumnPinOptionsDescriptionMetadata.a);
            }
            if (a.k(GridColumnPinOptionsDescriptionMetadata.a)) {
                return;
            }
            a.ab(GridColumnPinOptionsDescriptionMetadata.a);
        }
        static c(a) {
            GridColumnOptionsSimpleSectionBaseDescriptionMetadata.c(a);
            a.item("PinLeftCaption", "String");
            a.item("PinRightCaption", "String");
        }
        static d(a) {
            GridColumnPinOptionsDescriptionMetadata.b(a);
            a.ad("GridColumnPinOptions", () => new GridColumnPinOptionsDescription());
            a.ac("GridColumnPinOptions", GridColumnPinOptionsDescriptionMetadata.a);
        }
    }
    GridColumnPinOptionsDescriptionMetadata.$t = /*@__PURE__*/ markType(GridColumnPinOptionsDescriptionMetadata, 'GridColumnPinOptionsDescriptionMetadata');
    GridColumnPinOptionsDescriptionMetadata.a = null;
    return GridColumnPinOptionsDescriptionMetadata;
})();

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm2015/lib/GridColumnPinOptionsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GridColumnOptionsSimpleSectionBaseDescriptionMetadata } from "./GridColumnOptionsSimpleSectionBaseDescriptionMetadata";
import { GridColumnPinOptionsDescription } from "./GridColumnPinOptionsDescription";
/**
 * @hidden
 */
export let GridColumnPinOptionsDescriptionMetadata = /*@__PURE__*/ (() => {
    class GridColumnPinOptionsDescriptionMetadata extends Base {
        static b(a) {
            if (GridColumnPinOptionsDescriptionMetadata.a == null) {
                GridColumnPinOptionsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                GridColumnPinOptionsDescriptionMetadata.c(GridColumnPinOptionsDescriptionMetadata.a);
            }
            if (a.k(GridColumnPinOptionsDescriptionMetadata.a)) {
                return;
            }
            a.ac(GridColumnPinOptionsDescriptionMetadata.a);
        }
        static c(a) {
            GridColumnOptionsSimpleSectionBaseDescriptionMetadata.c(a);
            a.item("PinLeftCaption", "String");
            a.item("PinRightCaption", "String");
        }
        static d(a) {
            GridColumnPinOptionsDescriptionMetadata.b(a);
            a.ae("GridColumnPinOptions", () => new GridColumnPinOptionsDescription());
            a.ad("GridColumnPinOptions", GridColumnPinOptionsDescriptionMetadata.a);
        }
    }
    GridColumnPinOptionsDescriptionMetadata.$t = /*@__PURE__*/ markType(GridColumnPinOptionsDescriptionMetadata, 'GridColumnPinOptionsDescriptionMetadata');
    GridColumnPinOptionsDescriptionMetadata.a = null;
    return GridColumnPinOptionsDescriptionMetadata;
})();
